@@ -1,11 +1,6 @@
 var image_cropping = function ($) {
 
     function init() {
-      // set styles for size-warning
-      var style_img_warning = 'div.jcrop-image.size-warning .jcrop-vline{border:1px solid red; background: none;}' +
-                              'div.jcrop-image.size-warning .jcrop-hline{border:1px solid red; background: none;}';
-      $("<style type='text/css'>" + style_img_warning + "</style>").appendTo('head');
-
       $('input.image-ratio').each(function() {
         var $this = $(this),
         // find the image field corresponding to this cropping value
@@ -95,9 +90,15 @@ var image_cropping = function ($) {
           }
           var label = 'allow-fullsize-'+image_id;
           var checked = cropping_disabled ? '' : ' checked="checked"';
-          $('<div class="field-box allow-fullsize">' +
-                           '<input type="checkbox" id="'+label+'" name="'+label+'"'+checked+'></div>').appendTo($this.parent());
-          $('<style type="text/css">div.allow-fullsize{padding: 5px 0 0 10px;}</style>').appendTo('head');
+          var fullsize = $('<div class="field-box allow-fullsize">' +
+                           '<input type="checkbox" id="'+label+'" name="'+label+'"'+checked+'></div>');
+
+          if ($this.parent().find('.help').length) {
+            fullsize.insertBefore($this.parent().find('.help'));
+          } else {
+            fullsize.appendTo($this.parent());
+          }
+
           $('#'+label).click(function(){
             if (cropping_disabled === true){
               $this.val($this.val().substr(1));
@@ -117,12 +118,6 @@ var image_cropping = function ($) {
           });
         }
       });
-
-      if ($('body').hasClass('change-form')) {
-        // if we're in the Django admin, the holder needs to be floated
-        // so it clears the label
-        $("<style type='text/css'>div.jcrop-holder{float:left;}</style>").appendTo('head');
-      }
     }
 
     function max_cropping (width, height, image_width, image_height) {
